function [dati_plot fit] = test_validazione( m , data_val , K  ) 
% ingressi: 
% m: il modello in forma idmodel risultato della identificazione
% data_val: i dati in forma iddata per la validazione
% k: passi di predizione
% restituisce a schermo:
% fit, errore quadratico medio, numero fdt nulle, numero fdt quasi nulle 


%-impostare la TOLL a scelta\default
%- il tempo di campionamento lo recupero dalla struttura dati da_val
Mnpf = m;
%Mnpf= setPolyFormat(Mnpf, 'double'); %compatibility
Uf = data_val.u;
yf = data_val.y;
Ts = data_val.Ts;


y_stim=sim(Mnpf,Uf); % generale. sim il mod id con gli u futuri
err_qm=mean((yf-y_stim).^2);

fit = 100*(1 - norm(yf-y_stim)/norm(yf-mean(yf)));

dati_plot=[y_stim yf];

compare(data_val,Mnpf,K); 

